<?php
/**
 * Main plugin file.
 * This plugin extends the WooCommerce shop plugin with complete German language
 *    packs - formal and informal. - WooCommerce endlich komplett auf deutsch!
 *
 * @package   WooCommerce German (de_DE)
 * @author    David Decker
 * @link      http://deckerweb.de/twitter
 * @copyright Copyright (c) 2012-2013, David Decker - DECKERWEB
 *
 * Plugin Name: WooCommerce German (de_DE)
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/woocommerce-de/
 * Description: This plugin extends the WooCommerce shop plugin with complete German language packs - formal and informal. - WooCommerce endlich komplett auf deutsch!
 * Version: 3.0.1
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPL-2.0+
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: woocommerce-german
 * Domain Path: /wcde-languages/
 *
 * Copyright (c) 2012-2013 David Decker - DECKERWEB
 *
 *     This file is part of WooCommerce German (de_DE),
 *     a plugin for WordPress.
 *
 *     WooCommerce German (de_DE) is free software:
 *     You can redistribute it and/or modify it under the terms of the
 *     GNU General Public License as published by the Free Software
 *     Foundation, either version 2 of the License, or (at your option)
 *     any later version.
 *
 *     WooCommerce German (de_DE) is distributed in the hope that
 *     it will be useful, but WITHOUT ANY WARRANTY; without even the
 *     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *     PURPOSE. See the GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with WordPress. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Exit if accessed directly
 *
 * @since 3.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Setting constants
 *
 * @since 1.0.0
 */
/** Plugin directory */
define( 'WCDE_PLUGIN_DIR', dirname( __FILE__ ) );

/** Set constant path to the Plugin basename (folder) */
define( 'WCDE_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


add_action( 'init', 'ddw_wcde_init' );
/**
 * Load the text domain for translation of the plugin.
 * Load admin helper functions - only within 'wp-admin'.
 * 
 * @since 1.0.0
 *
 * @uses  load_plugin_textdomain()
 * @uses  is_admin()
 */
function ddw_wcde_init() {

	/** Load plugin textdomain plus translation files */
	load_plugin_textdomain( 'woocommerce-german', false, WCDE_PLUGIN_BASEDIR . '/wcde-languages/' );

	/** If 'wp-admin' include admin helper functions */
	if ( is_admin() ) {

		/** Include admin helper functions */
		require_once( WCDE_PLUGIN_DIR . '/includes/wcde-admin.php' );

	}  // end-if is_admin() check

	/** Add "Settings Page" link to plugin page - only within 'wp-admin' */
	if ( is_admin() && current_user_can( 'manage_woocommerce' ) ) {
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , 'ddw_wcde_settings_page_link' );
	}

	/** Include deprecated classes/ functions */
	require_once( WCDE_PLUGIN_DIR . '/includes/wcde-deprecated.php' );

}  // end of function ddw_wcde_init


add_action( 'plugins_loaded', 'ddw_wcde_setup_translation_loader', 5 );
/**
 * Translation loader - setup.
 *
 * @since 3.0.0
 *
 * @uses  WOOCOMMERCE_VERSION
 * @uses  version_compare()
 * @uses  is_admin()
 */
function ddw_wcde_setup_translation_loader() {

	/** Bail early if WooCommerce is not active */
	if ( ! defined( 'WOOCOMMERCE_VERSION' ) ) {

		return;

	}  // end-if WooCommerce check

	/** Load translations depending on WooCommerce version */
	if ( version_compare( WOOCOMMERCE_VERSION, '2.0.0' ) >= 0 ) {

		if ( is_admin() ) {

			/** WooCommerce 2.0+: Include plugin part for admin-only translations */
			require_once( WCDE_PLUGIN_DIR . '/includes/wcde-wctranslations-admin.php' );

		} else {

			/** WooCommerce 2.0+: Include plugin part for general/ frontend translations */
			require_once( WCDE_PLUGIN_DIR . '/includes/wcde-wctranslations-general.php' );

		}  // end-if is_admin() check

	} else {

		/** WooCommerce 1.6.x: Include plugin part for translations */
		require_once( WCDE_PLUGIN_DIR . '/includes/wcde-wctranslations-old1x.php' );

	}  // end-if WooCommerce version check

}  // end of function ddw_wcde_setup_translation_loader


/**
 * Include frontend helper functions for returning other order button strings.
 *
 * @since 2.1.0
 */
require_once( WCDE_PLUGIN_DIR . '/includes/wcde-frontend-helpers.php' );


/**
 * Enforce "Buttonlösung" default from language pack if no filter is active.
 *
 * @since 3.0.1
 *
 * @uses  __wcde_order_button_kaufen() Our helper function.
 */
if ( ! has_filter( 'woocommerce_order_button_text' ) ) {

	add_filter( 'woocommerce_order_button_text', '__wcde_order_button_kaufen' );

}  // end-if filter check


/**
 * Include Gettext helper functions for enforcing certain strings.
 *
 * @since 3.0.1
 */
require_once( WCDE_PLUGIN_DIR . '/includes/wcde-gettext-filters.php' );


/**
 * Returns current plugin's header data in a flexible way.
 *
 * @since  2.5.2
 *
 * @uses   get_plugins()
 *
 * @param  $wcde_plugin_value
 * @param  $wcde_plugin_folder
 * @param  $wcde_plugin_file
 *
 * @return string Plugin data.
 */
function ddw_wcde_plugin_get_data( $wcde_plugin_value ) {

	if ( ! function_exists( 'get_plugins' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	}

	$wcde_plugin_folder = get_plugins( '/' . plugin_basename( dirname( __FILE__ ) ) );
	$wcde_plugin_file = basename( ( __FILE__ ) );

	return $wcde_plugin_folder[ $wcde_plugin_file ][ $wcde_plugin_value ];

}  // end of function ddw_wcde_plugin_get_data